Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Command ¶ added in v1.4.0
type Command struct {
// contains filtered or unexported fields
}
Command holds configuration for generating a Go implementation of an interface, including destination, naming, and output structure.
func NewCommand ¶ added in v1.4.0
func NewCommand( dst string, interfaceName string, implementationName string, implementationPackageName string, singleFile bool, ) *Command
NewCommand creates a new Command with the given parameters. This struct is typically passed into a code generator to drive its behavior.
Click to show internal directories.
Click to hide internal directories.